#ifndef PROCWATCH_H
#define PROCWATCH_H

#include <QObject>
#include <stdlib.h>
#include <QTimer>
#include <iostream>
#include <stdio.h>
#include <unistd.h>
#include <QString>
#include <QIODevice>
#include <QTextStream>
#include <QFile>

#ifdef Q_WS_MAEMO_5
    #include <QMaemo5InformationBox>
#endif

class procwatch : public QObject
{
    Q_OBJECT
public:
    explicit procwatch(QObject *parent = 0);
    QTimer *timer;
    QString *procStatus;

signals:

public slots:
    void detectStatus();
    void startTimer();

private:

private slots:
};

#endif // PROCWATCH_H
